@@ -50,7 +50,7 @@ def attachSettings(settingsDict, enablePaypal=False):
         'compressor',
         'widget_tweaks',
         'paypal',
-    ) + get_core_apps()
+    ) + tuple(get_core_apps())
     
     ADDING_MIDDLEWARE_CLASSES = (
         'oscar.apps.basket.middleware.BasketMiddleware',
